diff src/globals.h @ 22442:73be82f278c0 v8.2.1769

patch 8.2.1769: popup filter interferes with using :normal to move the cursor Commit: https://github.com/vim/vim/commit/4934ad0e448bfa03ba19c7c5b411c457a9910442 Author: Bram Moolenaar <Bram@vim.org> Date: Mon Sep 28 22:29:58 2020 +0200 patch 8.2.1769: popup filter interferes with using :normal to move the cursor Problem: A popup filter interferes with using :normal to move the cursor in a popup. Solution: Do not invoke the filter when ex_normal_busy is set.
author Bram Moolenaar <Bram@vim.org>
date Mon, 28 Sep 2020 22:45:05 +0200
parents 00f2eebe74d9
children c271498e03b2
line wrap: on
line diff
--- a/src/globals.h
+++ b/src/globals.h
@@ -1150,12 +1150,9 @@ EXTERN typebuf_T typebuf		// typeahead b
 		    = {NULL, NULL, 0, 0, 0, 0, 0, 0, 0}
 #endif
 		    ;
-EXTERN int	ex_normal_busy INIT(= 0); // recursiveness of ex_normal()
-EXTERN int	ex_normal_lock INIT(= 0); // forbid use of ex_normal()
-#ifdef FEAT_PROP_POPUP
-// Set to TRUE when ex_normal_busy is set and out of typeahead.
-EXTERN int	ex_normal_busy_done INIT(= FALSE);
-#endif
+EXTERN int	ex_normal_busy INIT(= 0);   // recursiveness of ex_normal()
+EXTERN int	in_feedkeys INIT(= 0);	    // ex_normal_busy set in feedkeys()
+EXTERN int	ex_normal_lock INIT(= 0);   // forbid use of ex_normal()
 
 #ifdef FEAT_EVAL
 EXTERN int	ignore_script INIT(= FALSE);  // ignore script input